local mod = ...



-- Assets
-------------------------------------------------------------------------------------
mod:registerAssetProcessor("models/Bakery.fbx", { DataType = "BUILDING_ASSET_PROCESSOR" })
mod:registerAssetId("models/Bakery.fbx/Prefab/BakeryPart", "PREFAB_BAKERY")



-- Building Part: Barley Bakery -------------------------------------------------------------------------------------
mod:register({
	DataType = "BUILDING_PART",
	Id = "BARLEYBAKERY_PART",
	Name = "BARLEYBAKERY_PART_NAME", 
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = "PREFAB_BAKERY"
	},
	-- ConstructionVisual = "PREFAB_CONSTR_BARLEYFIELD",
	BuildingZone = { 
        ZoneEntryList = {
            { 
                Polygon = polygon.createRectangle( {5, 6}, {-1.5, 0.0} ),
                Type = { DEFAULT = true, NAVIGABLE = true, GRASS_CLEAR = true } 
			}
		}
	},
	AssetBuildingFunction = "BARLEYBAKERY_FUNCTION",
	Cost = {
		UpkeepCost = { { Resource = "GOLD_COINS", Quantity = 2 } },
		RessourcesNeeded = {
            { Resource = "WOOD", Quantity = 5 },
            { Resource = "TOOL", Quantity = 2 }
		}
	}
})



-- Resources: Bakery
-------------------------------------------------------------------------------------
mod:registerEnumValue ("RESOURCE_TYPE", "BRANBREAD_RESOURCE_TYPE")
mod:registerAssetId("icons/breadbran.png", "ICON_BRANBREAD")

mod:register({
	DataType = "RESOURCE",
	Id = "BRANBREAD_RESOURCE",
	ResourceName = "BRANBREAD_RESOURCE_NAME",
	Icon = "ICON_BRANBREAD",
	ResourceTypeList = { "BRANBREAD_RESOURCE_TYPE" },
	IsTradable = false,
	ResourceLayoutType = "CRATES",
	VillagerBuyingPrice = { Resource = "GOLD", Quantity = 3 },
	DisplayInInventory = true
})



-- Building Function: Bakery
-------------------------------------------------------------------------------------
mod:register({
		DataType = "BUILDING_FUNCTION_MARKET",
        Id = "BARLEYBAKERY_FUNCTION",
		Name = "BARLEYBAKERY_FUNCTION_NAME",
		IsPrivate = false,
		WorkerCapacity = 1,
		RelatedJob = { 
			Job = "JOB_BRANBREADBAKER", 
			Behavior = "BEHAVIOR_WORK"
		},
		TypeList = { "BRANBREAD_RESOURCE_TYPE" },
		IsOverrideCapacity = true,
		CapacityPerSlot = 50,
		InputInventoryCapacity = {
			{ Resource = "WATER", Quantity = 20 },
			{ Resource = "MILLED_BARLEY_RESOURCE", Quantity = 20 },
		},
		ResourceListNeeded = {
			{ Resource = "WATER", Quantity = 1 },
			{ Resource = "MILLED_BARLEY_RESOURCE", Quantity = 1 },
		},
		ResourceProduced = {
			{ Resource = "BRANBREAD_RESOURCE", Quantity = 1 },
		}
})



mod:override({
	Id = "NEED_FOOD",
	NeedTypeList = {
		Action = "APPEND",
		"BRANBREAD_RESOURCE_TYPE"
	}
})



-- Job: Bran Bread Baker
-------------------------------------------------------------------------------------
mod:register({
	DataType = "JOB",
	Id = "JOB_BRANBREADBAKER",
	JobName = "JOB_BRANBREADBAKER_NAME",
	JobDescription = "JOB_BRANBREADBAKER_DESC",
	IsLockedByDefault = false,
	DefaultBehavior = "BEHAVIOR_WORK",
	UseWorkplaceBehavior = true,
    ProductionDelay = 30, -- default 30
	AssetJobProgression = "DEFAULT_JOB_PROGRESSION",
	CharacterSetup = {
		DataType = "CHARACTER_SETUP", 
		-- RightHandObject = {
			-- Model = "PREFAB_TOOL_CHEESE_MAKER_SPOON",
			-- KeepObjectOnWalkCycle = false
		-- },
		-- LeftHandObject = {
			-- Model = "PREFAB_TOOL_FARMER_SEED_BAG",
			-- KeepObjectOnWalkCycle = false
		-- },
		WalkAnimation = "WALKING",
		IdleAnimation = "BAKERY"
	}
})



mod:override({
    Id = "NEWCOMER",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_BRANBREADBAKER"
    }
})



mod:override({
    Id = "SERF",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_BRANBREADBAKER"
    }
})


mod:override({
    Id = "COMMONER",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_BRANBREADBAKER"
    }
})



-- Paths: Bakery
-------------------------------------------------------------------------------------
mod:registerAssetId("models/Bakery.fbx/Prefab/BakeryPart/pathA", "BAKERY_PATHA")
mod:registerAssetId("models/Bakery.fbx/Prefab/BakeryPart/pathB", "BAKERY_PATHB")
mod:registerAssetId("models/Bakery.fbx/Prefab/BakeryPart/pathC", "BAKERY_PATHC")

mod:registerPrefabComponent("models/Bakery.fbx/Prefab/BakeryPart", {
    DataType = "COMP_BUILDING_PART",
    PathList = {
        {
            PathType = BUILDING_PATH_TYPE.PICKUP,
            WayPointList = { "BAKERY_PATHA" }
        },
        {
            PathType = BUILDING_PATH_TYPE.PICKUP,
            WayPointList = { "BAKERY_PATHB" }
        },
        {
            PathType = BUILDING_PATH_TYPE.DEFAULT,
            WayPointList = { "BAKERY_PATHC" }
        },
    }
})



-- Construction Visual
-----------------------------------------------------------------------------------
mod:registerAssetId("models/Bakery.fbx/Prefab/ConstructionVisual", "PREFAB_CONSTR_BUILDING_PART_BAKERY")



-- Grounding
-----------------------------------------------------------------------------------
mod:registerPrefabComponent("models/Bakery.fbx/Prefab/BakeryPart/barrel-water", {DataType = "COMP_GROUNDED"})
mod:registerPrefabComponent("models/Bakery.fbx/Prefab/BakeryPart/barrel-crates", {DataType = "COMP_GROUNDED"})
mod:registerPrefabComponent("models/Bakery.fbx/Prefab/BakeryPart/sackrack", {DataType = "COMP_GROUNDED"})
mod:registerPrefabComponent("models/Bakery.fbx/Prefab/BakeryPart/table", {DataType = "COMP_GROUNDED"})
mod:registerPrefabComponent("models/Bakery.fbx/Prefab/BakeryPart/Oven", {DataType = "COMP_GROUNDED"})


