local mod = ...



-- Assets
-------------------------------------------------------------------------------------
mod:registerAssetProcessor("models/BarleyFarm.fbx", { DataType = "BUILDING_ASSET_PROCESSOR" })
mod:registerAssetId("models/BarleyFarm.fbx/Prefab/BarleyFieldPart", "PREFAB_BARLEYFIELD")



-- Monument: Barley Farm
-------------------------------------------------------------------------------------
mod:register({
	DataType = "BUILDING", 
	Id = "BUILDING_BARLEYFARM",
	Name = "BUILDING_BARLEYFARM_NAME",
	Description = "BUILDING_BARLEYFARM_DESC",
	BuildingType = "GENERAL",
	AssetCoreBuildingPart = "BUILDING_PART_MONUMENT_POLE",
	IsEditable = true,
	BuildingPartSetList = {
		{
			Name = "BUILDING_SET_BARLEYFARM1_NAME",
			BuildingPartList = { 
				"BARLEYFIELD_PART",
			}
		},
		{
			Name = "BUILDING_SET_BARLEYFARM2_NAME",
			BuildingPartList = { 
				"BARLEYMILL_PART",
			}
		},
		{
			Name = "BUILDING_SET_BARLEYFARM3_NAME",
			BuildingPartList = { 
				"GRUELPOT_PART",
			}
		},
		{
			Name = "BUILDING_SET_BARLEYFARM4_NAME",
			BuildingPartList = { 
				"BARLEYBAKERY_PART"
			}
		},		
    }
})



-- Building Part: Barley Field
-------------------------------------------------------------------------------------
mod:register({
	DataType = "BUILDING_PART",
	Id = "BARLEYFIELD_PART",
	Name = "BARLEYFIELD_PART_NAME",
	Description = "BARLEYFIELD_PART_DESC",
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = "PREFAB_BARLEYFIELD"
	},
	ConstructionVisual = "PREFAB_CONSTR_BUILDING_PART_BARLEYFIELD",
	BuildingZone = { 
        ZoneEntryList = {
            { 
                Polygon = polygon.createRectangle( {8.0, 8.5}, {-1.2, 0.0} ),
                Type = { DEFAULT = true, NAVIGABLE = true, GRASS_CLEAR = true } 
			},
		}
	},
	AssetBuildingFunction = "BARLEYFIELD_FUNCTION",
	Cost = {
		BuildRightTaxes = {	{ Resource = "GOLD", Quantity = 15 } },
		UpkeepCost = { { Resource = "GOLD", Quantity = 5 } },
		RessourcesNeeded = {
            { Resource = "WOOD", Quantity = 7 },
            { Resource = "TOOL", Quantity = 3 }
		}
	}
})



-- Resources: Barley Farm
-------------------------------------------------------------------------------------
mod:registerAssetId("icons/barley.png", "ICON_BARLEY")

mod:register({
	DataType = "RESOURCE",
	Id = "BARLEY_RESOURCE",
	ResourceName = "BARLEY_RESOURCE_NAME",
	Icon = "ICON_BARLEY",
	ResourceTypeList = { "GRANARY" },
	IsTradable = true,
	ResourceLayoutType = "CRATES",
	DisplayInInventory = true
})



-- Building Function: Barley Field
-------------------------------------------------------------------------------------
mod:register({
    DataType = "BUILDING_FUNCTION_FARM",
    Id = "BARLEYFIELD_FUNCTION",
    Name = "BARLEYFIELD_FUNCTION_NAME",
    WorkerCapacity = 3,
    RelatedJob = { 
        Job = "JOB_BARLEYFARMER", 
        Behavior = "BEHAVIOR_FARMER"
    },
    ResourceListNeeded = {
		{ Resource = "BARLEY_RESOURCE", Quantity = 1 },
	},
	ResourceProduced = {
		{ Resource = "BARLEY_RESOURCE", Quantity = 1 },
	},
	
    -- Max total cycle is 21 days, beyond that will be cut short
    SowingDurationPerc = {0, 4},
	GrowDuration = {4, 8},
	GrowWaitDuration = {8, 10},
	HarvestDuration = {10, 18},
	RestDuration = {18, 21},

	QuantityToPlantPerStep = 30, -- default 30
	PlantingStepsCount = 5, -- default 5
    QuantityToHarvestPerStep = 30, -- default 30
	HarvestStepsCount = 5, -- default 5
	ResourceValuePerGather = 0.05, -- default 1.00
		-- QuantityToHarvestPerStep x HarvestStepsCount x ResourceValuePerGather = how many they bring in each time
		
    CropFieldConfig = "FARM_FIELD_CONFIG_BARLEYFIELD",
    GrowingSetup = "AGENT_WORKSTATION_SETUP_BARLEYFIELD_GROWING", 
    SowingSetup = "AGENT_WORKSTATION_SETUP_BARLEYFIELD_SOWING", 
    HarvestSetup = "AGENT_WORKSTATION_SETUP_BARLEYFIELD_HARVEST"
})



-- Barley Crop
-------------------------------------------------------------------------------------
mod:registerPrefabComponent("models/BarleyFarm.fbx/Prefab/Barley", { DataType = "COMP_CROP_FIELD_ELEMENT" })

mod:registerAssetId("models/BarleyFarm.fbx/Prefab/Barley", "PREFAB_PLANT_BARLEY")
mod:registerAssetId("models/BarleyFarm.fbx/Materials/Barley", "MATERIAL_BARLEY")
mod:registerAssetId("models/textures/Colors.png", "TEXTURE_BARLEY")

mod:override({
    Id = "MATERIAL_BARLEY",
    HasAlphaTest = true,
	BackFaceVisible = true
})



-- Plantable
-------------------------------------------------------------------------------------
mod:registerPrefabComponent("models/BarleyFarm.fbx/Prefab/Barley", { DataType = "COMP_PLANTABLE", MinSpaceBetweenPlant = 0.2 })

mod:register({
    DataType = "PLANTABLE",
    Id = "PLANTABLE_BARLEY",
    Name = "PLANTABLE_BARLEY_NAME",
    PlantPrefab = "PREFAB_PLANT_BARLEY",
    MinimumScale = 0.85, -- default 0.0
    MaximumScale = 1.15 -- default 1.0
})



-- Resource Container
-------------------------------------------------------------------------------------
mod:registerPrefabComponent( "models/BarleyFarm.fbx/Prefab/Barley", {
    DataType = "COMP_RESOURCE_CONTAINER",
    ResourceData = "BARLEY_RESOURCE",
    IsReplenishable = false,
    ResourceValue = 1, -- default 1.0
    AvailableQuantity = 1, -- default 1
    Radius = 2.00, -- default 1.25, distance the villager will stand to sow/harvest
    IsDestroyWhenEmpty = true,
    HasMaximumWorkstation = false
})



-- Zone
-------------------------------------------------------------------------------------
mod:register({
    DataType = "ZONE",
    Id = "ZONE_BARLEYFIELD",
    Name = "ZONE_BARLEYFIELD_NAME",
    Description = "ZONE_BARLEYFIELD_DESC",
    Color = {1.00, 1.70, 0.60, 0.9}, -- RGB A = 
    DesirabilityLayerToShow = "DESIRABILITY_FERTILITY"
})



-- Farm Field Config
-------------------------------------------------------------------------------------
mod:register({
    DataType = "FARM_FIELD_CONFIG",
    Id = "FARM_FIELD_CONFIG_BARLEYFIELD",
    ZoneType = "ZONE_BARLEYFIELD",
    PlantPrefab = "PREFAB_PLANT_BARLEY",
    HasPlantingCycle = true,
    IsScaling = true,
    RowDistance = 0.75, -- default 3.0
    ItemDistance = 0.75, -- default 2.0
    RandomOrientation = {0, 360},
    RandomPositionOffset = {-0.2, 0.2},
	-- StartScaleValue = 0.15, -- default 0.15
    SourceMaterial = "MATERIAL_BARLEY",
    GrowingMaterial = "MATERIAL_BARLEY",
    HarvestedMaterial = "MATERIAL_BARLEY",
    GrowingTextureList = {
        "TEXTURE_BARLEY",
    },
    HarvestingTextureList = {
        "TEXTURE_BARLEY",
    },
    AlphaTestThreshold = 0.5
})



-- Sowing Setup
-------------------------------------------------------------------------------------
mod:register({
    DataType = "AGENT_WORKSTATION_SETUP",
    Id = "AGENT_WORKSTATION_SETUP_BARLEYFIELD_SOWING",
	CharacterSetup = {
        DataType = "CHARACTER_SETUP",
        LeftHandObject = {
            Model = "PREFAB_TOOL_FARMER_SEED_BAG", 
            WorkAttachName = "SeedBag_Anchor", 
			WalkAttachName = "SeedBag_Anchor",
			KeepObjectOnWalkCycle = true
        },
        WalkAnimation = "SEED_WALK",
        IdleAnimation = "SEED"
	}
})



-- Growing Setup
-------------------------------------------------------------------------------------
mod:register({
    DataType = "AGENT_WORKSTATION_SETUP",
    Id = "AGENT_WORKSTATION_SETUP_BARLEYFIELD_GROWING",
	CharacterSetup = {
        DataType = "CHARACTER_SETUP",
        WalkAnimation = "WALKING",
        IdleAnimation = "GRAPE_CARING"
	}
})



-- Harvest Setup
-------------------------------------------------------------------------------------
mod:register({
    DataType = "AGENT_WORKSTATION_SETUP",
    Id = "AGENT_WORKSTATION_SETUP_BARLEYFIELD_HARVEST",
	CharacterSetup = {
        DataType = "CHARACTER_SETUP",
        RightHandObject = {
			Model = "PREFAB_TOOL_FARMER_SICKLE",
            WorkAttachName = "Sickle_Anchor",
			-- WalkAttachName = "Sickle_Anchor",
			KeepObjectOnWalkCycle = true
        },
        WalkAnimation = "SCYTHE_WALK",
		IdleAnimation = "SCYTHE"
	}
})



-- Job: Barley Farmer
-----------------------------------------------------------------------------------
mod:registerAssetId("models/BarleyFarm.fbx/Prefab/HatPart3", "PREFAB_HAT_FARMER3") -- BROWN - UNISEX hat, hair



mod:register({
	DataType = "JOB",
	Id = "JOB_BARLEYFARMER",
	JobName = "JOB_BARLEYFARMER_NAME",
	JobDescription = "JOB_BARLEYFARMER_DESC",
	IsLockedByDefault = false,
	DefaultBehavior = "BEHAVIOR_FARMER",
	UseWorkplaceBehavior = true,
    ProductionDelay = 0.01, -- default 30
	AssetJobProgression = "DEFAULT_JOB_PROGRESSION",
	CharacterSetup = {
		DataType = "CHARACTER_SETUP",
		FemaleHatList = {
            "PREFAB_HAT_FARMER3",
        }, 
        MaleHatList = {
            "PREFAB_HAT_FARMER3",
        },
		WalkAnimation = "WALKING",
		IdleAnimation = "IDLE"
	}
})

mod:override({
    Id = "NEWCOMER",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_BARLEYFARMER"
    }
})

mod:override({
    Id = "SERF",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_BARLEYFARMER"
    }
})



-- Construction Visual
-----------------------------------------------------------------------------------
mod:registerAssetId("models/BarleyFarm.fbx/Prefab/ConstructionVisual", "PREFAB_CONSTR_BUILDING_PART_BARLEYFIELD")


-- Grounding
-----------------------------------------------------------------------------------
mod:registerPrefabComponent("models/BarleyFarm.fbx/Prefab/BarleyFieldPart/rack-seed", {DataType = "COMP_GROUNDED"})
mod:registerPrefabComponent("models/BarleyFarm.fbx/Prefab/BarleyFieldPart/rack-tools", {DataType = "COMP_GROUNDED"})
mod:registerPrefabComponent("models/BarleyFarm.fbx/Prefab/BarleyFieldPart/sheafs1", {DataType = "COMP_GROUNDED"})
mod:registerPrefabComponent("models/BarleyFarm.fbx/Prefab/BarleyFieldPart/sheafs2", {DataType = "COMP_GROUNDED"})
mod:registerPrefabComponent("models/BarleyFarm.fbx/Prefab/BarleyFieldPart/sheafs3", {DataType = "COMP_GROUNDED"})
mod:registerPrefabComponent("models/BarleyFarm.fbx/Prefab/BarleyFieldPart/structure", {DataType = "COMP_GROUNDED"})
mod:registerPrefabComponent("models/BarleyFarm.fbx/Prefab/BarleyFieldPart/wheelbarrow", {DataType = "COMP_GROUNDED"})



