local mod = ...



-- Assets
-------------------------------------------------------------------------------------
mod:registerAssetProcessor("models/BarleyMill.fbx", { DataType = "BUILDING_ASSET_PROCESSOR" })
mod:registerAssetId("models/BarleyMill.fbx/Prefab/BarleyMillPart", "PREFAB_BARLEYMILL")



-- Building Part: Barley Mill
-------------------------------------------------------------------------------------
mod:register({
	DataType = "BUILDING_PART",
	Id = "BARLEYMILL_PART",
	Name = "BARLEYMILL_PART_NAME", 
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = "PREFAB_BARLEYMILL"
	},
	ConstructionVisual = "PREFAB_CONSTR_BUILDING_PART_BARLEYMILL",
	BuildingZone = { 
        ZoneEntryList = {
            { 
                Polygon = polygon.createRectangle( {7, 11}, {3.0, -2.0} ),
                Type = { DEFAULT = true, NAVIGABLE = true, GRASS_CLEAR = true } 
			}
		}
	},
	AssetBuildingFunction = "BARLEYMILL_FUNCTION",
	Cost = {
		BuildRightTaxes = {	{ Resource = "GOLD", Quantity = 25 } },
		UpkeepCost = { { Resource = "GOLD", Quantity = 5 } },
		RessourcesNeeded = {
			{ Resource = "STONE", Quantity = 5 },
            { Resource = "WOOD", Quantity = 10 },
            { Resource = "TOOL", Quantity = 5 }
		}
	}
})



-- Resources: Barley Mill
-------------------------------------------------------------------------------------
mod:registerAssetId("icons/barleymilled.png", "ICON_BARLEYMILLED")

mod:register({
	DataType = "RESOURCE",
	Id = "MILLED_BARLEY_RESOURCE",
	ResourceName = "MILLED_BARLEY_RESOURCE_NAME",
	Icon = "ICON_BARLEYMILLED",
	ResourceTypeList = { "GRANARY" },
	IsTradable = true,
	ResourceLayoutType = "CRATES",
	DisplayInInventory = true
})



-- Building Function: Barley Mill
-------------------------------------------------------------------------------------
mod:register({
    DataType = "BUILDING_FUNCTION_WORKPLACE",
    Id = "BARLEYMILL_FUNCTION",
    Name = "BARLEYMILL_FUNCTION_NAME",
    WorkerCapacity = 2,
    RelatedJob = { 
        Job = "JOB_BARLEYMILLER", 
        Behavior = "BEHAVIOR_WORK"
    },
    InputInventoryCapacity = {
		{ Resource = "BARLEY_RESOURCE", Quantity = 60 },
	},
    ResourceListNeeded = {
		{ Resource = "BARLEY_RESOURCE", Quantity = 3 },
	},
	ResourceProduced = {{ Resource = "MILLED_BARLEY_RESOURCE", Quantity = 1 }}

})



-- Job: Barley Miller
-----------------------------------------------------------------------------------
mod:register({
	DataType = "JOB",
	Id = "JOB_BARLEYMILLER",
	JobName = "JOB_BARLEYMILLER_NAME",
	JobDescription = "JOB_BARLEYMILLER_DESC",
	IsLockedByDefault = false,
	DefaultBehavior = "BEHAVIOR_WORK",
	UseWorkplaceBehavior = true,
    ProductionDelay = 30, -- default 30
	AssetJobProgression = "DEFAULT_JOB_PROGRESSION",
	CharacterSetup = {
		DataType = "CHARACTER_SETUP",
		WalkAnimation = "WALKING",
		IdleAnimation = "IDLE"
	}
})

mod:override({
    Id = "NEWCOMER",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_BARLEYMILLER"
    }
})

mod:override({
    Id = "SERF",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_BARLEYMILLER"
    }
})

mod:override({
    Id = "COMMONER",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_BARLEYMILLER"
    }
})


-- Custom Component
-------------------------------------------------------------------------------------

local COMP_ROTATEX1 = {
    TypeName = "COMP_ROTATEX1",
    ParentType = "COMPONENT",
    Properties = {
        { Name = "RotationSpeedX", Type = "float", Default = 0.1 },
    }
}

function COMP_ROTATEX1:create()
    self._timer = 0
end

function COMP_ROTATEX1:init()
    self._rotationX = 0
end

function COMP_ROTATEX1:update()
    local dt = self:getLevel():getDeltaTime()
    self._rotationX = self._rotationX - self.RotationSpeedX * dt
    self:getOwner():setRotationX(self._rotationX)
end

mod:registerClass(COMP_ROTATEX1)
-- mod:registerAssetId("models/BarleyMill.fbx/Prefab/BarleyMillPart/sweeps", "PREFAB_BARLEYMILL_SWEEPS")

mod:registerPrefabComponent("models/BarleyMill.fbx/Prefab/BarleyMillPart/sweeps", {
	DataType = "COMP_ROTATEX1",
	Enabled = true
})

-- mod:registerPrefabComponent("models/BarleyMill.fbx/Prefab/BarleyMillPart/sweeps", {
    -- DataType = "COMP_BUILDING_PART",
    -- FeedbackComponentListToActivate = {
		-- { "PREFAB_BARLEYMILL_SWEEPS", "COMP_ROTATEX1" }
    -- }
-- })



-- Construction Visual
-----------------------------------------------------------------------------------
mod:registerAssetId("models/BarleyMill.fbx/Prefab/ConstructionVisual", "PREFAB_CONSTR_BUILDING_PART_BARLEYMILL")



-- Grounding
-----------------------------------------------------------------------------------
mod:registerPrefabComponent("models/BarleyMill.fbx/Prefab/BarleyMillPart/roof-thatch", {DataType = "COMP_GROUNDED"})
mod:registerPrefabComponent("models/BarleyMill.fbx/Prefab/BarleyMillPart/sheafs1", {DataType = "COMP_GROUNDED"})
mod:registerPrefabComponent("models/BarleyMill.fbx/Prefab/BarleyMillPart/sheafs2", {DataType = "COMP_GROUNDED"})
mod:registerPrefabComponent("models/BarleyMill.fbx/Prefab/BarleyMillPart/sacks", {DataType = "COMP_GROUNDED"})
mod:registerPrefabComponent("models/BarleyMill.fbx/Prefab/BarleyMillPart/wheelbarrow", {DataType = "COMP_GROUNDED"})
