local mod = ...



-- Assets
-------------------------------------------------------------------------------------
mod:registerAssetProcessor("models/GruelVendor.fbx", { DataType = "BUILDING_ASSET_PROCESSOR" })
mod:registerAssetId("models/GruelVendor.fbx/Prefab/GruelVendorPart", "PREFAB_GRUELPOT")



-- Gruel Vendor
-------------------------------------------------------------------------------------
-- mod:register({
	-- DataType = "BUILDING", 
	-- Id = "BUILDING_GRUELVENDOR",
	-- Name = "BUILDING_GRUELVENDOR_NAME",
	-- Description = "BUILDING_GRUELVENDOR_DESC",
	-- BuildingType = "GENERAL",
	-- AssetCoreBuildingPart = "GRUELPOT_PART",
	-- BuildingPartSetList = {
		-- {
			-- Name = "BUILDING_SET_GRUELVENDOR_NAME",
			-- BuildingPartList = { "GRUELPOT_PART" }
		-- }
    -- }
-- })



-- Building Part: Gruel Pot
-------------------------------------------------------------------------------------
mod:register({
	DataType = "BUILDING_PART",
	Id = "GRUELPOT_PART",
	Name = "GRUELPOT_PART_NAME", 
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = "PREFAB_GRUELPOT"
	},
	ConstructionVisual = "PREFAB_CONSTR_BUILDING_PART_GRUELVENDOR",
	BuildingZone = { 
		ZoneEntryList = {
			{ 
				Polygon = polygon.createRectangle( {4.2, 5}, {0, 1} ),
				Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = true } 
			}
		}
	},
	AssetBuildingFunction = "GRUELPOT_FUNCTION",
	Cost = {
        UpkeepCost = { { Resource = "GOLD_COINS", Quantity = 2 } },
        RessourcesNeeded = {
            { Resource = "WOOD", Quantity = 5 },
		}
	}
})



-- Resources: Gruel Vendor
-------------------------------------------------------------------------------------
mod:registerEnumValue ("RESOURCE_TYPE", "GRUEL_RESOURCE_TYPE")
mod:registerAssetId("icons/gruel.png", "ICON_GRUEL")

mod:register({
	DataType = "RESOURCE",
	Id = "GRUEL_RESOURCE",
	ResourceName = "GRUEL_RESOURCE_NAME",
	Icon = "ICON_GRUEL",
	ResourceTypeList = { "GRUEL_RESOURCE_TYPE" },
	IsTradable = false,
	ResourceLayoutType = "CRATES",
	VillagerBuyingPrice = { Resource = "GOLD", Quantity = 3 },
	DisplayInInventory = true
})




-- Building Function: Gruel Vendor
-------------------------------------------------------------------------------------
mod:register({
		DataType = "BUILDING_FUNCTION_MARKET",
        Id = "GRUELPOT_FUNCTION",
		Name = "GRUELPOT_FUNCTION_NAME",
		IsPrivate = false,
		WorkerCapacity = 1,
		RelatedJob = { 
			Job = "JOB_GRUELVENDOR", 
			Behavior = "BEHAVIOR_WORK"
		},
		TypeList = { "GRUEL_RESOURCE_TYPE" },
		IsOverrideCapacity = true,
		CapacityPerSlot = 50,
		InputInventoryCapacity = {
			{ Resource = "WATER", Quantity = 25 },
			{ Resource = "MILLED_BARLEY_RESOURCE", Quantity = 5 },
		},
		ResourceListNeeded = {
			{ Resource = "WATER", Quantity = 3 },
			{ Resource = "MILLED_BARLEY_RESOURCE", Quantity = 1 },
		},
		ResourceProduced = {
			{ Resource = "GRUEL_RESOURCE", Quantity = 3 },
		}
})



mod:override({
	Id = "NEED_FOOD",
	NeedTypeList = {
		Action = "APPEND",
		"GRUEL_RESOURCE_TYPE"
	}
})



-- Job: Gruel Vendor
-------------------------------------------------------------------------------------
mod:register({
	DataType = "JOB",
	Id = "JOB_GRUELVENDOR",
	JobName = "JOB_GRUELVENDOR_NAME",
	JobDescription = "JOB_GRUELVENDOR_DESC",
	IsLockedByDefault = false,
	DefaultBehavior = "BEHAVIOR_WORK",
	UseWorkplaceBehavior = true,
    ProductionDelay = 30, -- default 30
	AssetJobProgression = "DEFAULT_JOB_PROGRESSION",
	CharacterSetup = {
		DataType = "CHARACTER_SETUP", 
		RightHandObject = {
			Model = "PREFAB_TOOL_CHEESE_MAKER_SPOON",
			KeepObjectOnWalkCycle = false
		},
		LeftHandObject = {
			Model = "PREFAB_TOOL_FARMER_SEED_BAG",
			KeepObjectOnWalkCycle = false
		},
		WalkAnimation = "WALKING",
		IdleAnimation = "BARREL_MAKING"
	}
})



mod:override({
    Id = "NEWCOMER",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_GRUELVENDOR"
    }
})



mod:override({
    Id = "SERF",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_GRUELVENDOR"
    }
})



-- Paths: Gruel Pot
-------------------------------------------------------------------------------------
mod:registerAssetId("models/GruelVendor.fbx/Prefab/GruelVendorPart/pathA", "GRUELPOT_PATHA")
mod:registerAssetId("models/GruelVendor.fbx/Prefab/GruelVendorPart/pathB", "GRUELPOT_PATHB")
mod:registerAssetId("models/GruelVendor.fbx/Prefab/GruelVendorPart/pathC", "GRUELPOT_PATHC")
mod:registerAssetId("models/GruelVendor.fbx/Prefab/GruelVendorPart/pathD", "GRUELPOT_PATHD")

mod:registerPrefabComponent("models/GruelVendor.fbx/Prefab/GruelVendorPart", {
    DataType = "COMP_BUILDING_PART",
    PathList = {
        {
            PathType = BUILDING_PATH_TYPE.PICKUP,
            WayPointList = { "GRUELPOT_PATHA" }
        },
        {
            PathType = BUILDING_PATH_TYPE.PICKUP,
            WayPointList = { "GRUELPOT_PATHB" }
        },
        {
            PathType = BUILDING_PATH_TYPE.PICKUP,
            WayPointList = { "GRUELPOT_PATHC" }
        },
        {
            PathType = BUILDING_PATH_TYPE.DEFAULT,
            WayPointList = { "GRUELPOT_PATHD" }
        },
    }
})



-- Construction Visual
-----------------------------------------------------------------------------------
mod:registerAssetId("models/GruelVendor.fbx/Prefab/ConstructionVisual", "PREFAB_CONSTR_BUILDING_PART_GRUELVENDOR")



-- Grounding
-----------------------------------------------------------------------------------
mod:registerPrefabComponent("models/GruelVendor.fbx/Prefab/GruelVendorPart/cauldron", {DataType = "COMP_GROUNDED"})
mod:registerPrefabComponent("models/GruelVendor.fbx/Prefab/GruelVendorPart/counter", {DataType = "COMP_GROUNDED"})
mod:registerPrefabComponent("models/GruelVendor.fbx/Prefab/GruelVendorPart/poles", {DataType = "COMP_GROUNDED"})
mod:registerPrefabComponent("models/GruelVendor.fbx/Prefab/GruelVendorPart/sacks", {DataType = "COMP_GROUNDED"})


